@@ -134,7 +134,7 @@ public class LoginPageByFormActionRegexStep extends AbstractStep<HtmlPage, Objec
                     }
                 }
                 if (!linkAvailable) {
-                    LOG.error("Page that does not have the link to imply a successful login : " + output.getWebResponse().getContentAsString());
+                    LOG.debug("Page that does not have the link to imply a successful login : " + output.getWebResponse().getContentAsString());
 //                    if (isDebuggingEnabled()){
 //                        openPageInBrowser(output);
 //                    }
